# mdblog
markdown blog server

### view demo
[demo](mdblog/data/demo.md)

### install
```shell script
pip3 install mdblog 
```

### usage
```shell script
mdblog run
# run with config file
mdblog run --config ./config.toml

```